From e8bc18069cf3bfe963f2a221b811405dd1336f14 Mon Sep 17 00:00:00 2001
From: Sachin Sundar <ssundar@codeaurora.org>
Date: Tue, 8 Mar 2016 16:34:39 +0530
Subject: [PATCH] Add disabled option for firewall

Signed-off-by: Sachin Sundar <ssundar@codeaurora.org>
---
 defaults.c |    2 ++
 main.c     |   27 ++++++++++++++++++++++++---
 options.h  |    1 +
 3 files changed, 27 insertions(+), 3 deletions(-)

diff --git a/defaults.c b/defaults.c
index 396cbf7..4bab3ee 100644
--- a/defaults.c
+++ b/defaults.c
@@ -67,6 +67,8 @@ const struct fw3_option fw3_flag_opts[] = {
 	FW3_OPT("custom_chains",       bool,     defaults, custom_chains),
 	FW3_OPT("disable_ipv6",        bool,     defaults, disable_ipv6),
 
+	FW3_OPT("disabled",            bool,     defaults, disabled),
+
 	FW3_OPT("__flags_v4",          int,      defaults, flags[0]),
 	FW3_OPT("__flags_v6",          int,      defaults, flags[1]),
 
diff --git a/main.c b/main.c
index 71463ae..8fe7f4f 100644
--- a/main.c
+++ b/main.c
@@ -554,7 +554,14 @@ int main(int argc, char **argv)
 	{
 		if (fw3_lock())
 		{
-			rv = start();
+			if (!defs->disabled)
+			{
+				rv = start();
+			}
+			else
+			{
+				warn("Firewall disabled in configuration!!");
+			}
 			fw3_unlock();
 		}
 	}
@@ -579,7 +586,14 @@ int main(int argc, char **argv)
 		if (fw3_lock())
 		{
 			stop(true);
-			rv = start();
+			if (!defs->disabled)
+			{
+				rv = start();
+			}
+			else
+			{
+				warn("Firewall disabled in configuration!!");
+			}
 			fw3_unlock();
 		}
 	}
@@ -587,7 +601,14 @@ int main(int argc, char **argv)
 	{
 		if (fw3_lock())
 		{
-			rv = reload();
+			if (!defs->disabled)
+			{
+				rv = reload();
+			}
+			else
+			{
+				warn("Firewall disabled in configuration!!");
+			}
 			fw3_unlock();
 		}
 	}
diff --git a/options.h b/options.h
index a2bacce..e3e22f1 100644
--- a/options.h
+++ b/options.h
@@ -265,6 +265,7 @@ struct fw3_defaults
 	bool drop_invalid;
 
 	bool syn_flood;
+	bool disabled;
 	struct fw3_limit syn_flood_rate;
 
 	bool tcp_syncookies;
-- 
1.7.9.5

